{
  description = "Matrix Monzo bot";

  inputs = {
    nixpkgs.url = "nixpkgs/nixos-23.11";
    utils.url = "github:numtide/flake-utils";
    naersk = {
      url = "github:nix-community/naersk";
      inputs.nixpkgs.follows = "nixpkgs";
    };
  };

  outputs = { self, nixpkgs, utils, naersk }:
    utils.lib.eachDefaultSystem (system: let
      pkgs = nixpkgs.legacyPackages."${system}";
      naersk-lib = naersk.lib."${system}";
    in rec {
      # `nix build`
      packages.mxmonzo = naersk-lib.buildPackage {
        pname = "mxmonzo";
        root = ./.;

        buildInputs = with pkgs; [
          openssl
          pkg-config
        ];
      };

      defaultPackage = packages.mxmonzo;

      # NixOS Modules
      nixosModules = {
        mxmonzo = import ./nixos_modules/mxmonzo.nix self;
      };

      # `nix run`
      apps.mxmonzo = utils.lib.mkApp {
        drv = packages.mxmonzo;
      };
      defaultApp = apps.mxmonzo;

      # `nix develop`
      devShell = pkgs.mkShell {
        nativeBuildInputs = with pkgs; [ rustc cargo openssl pkg-config ];
      };
    });
}
